#
# This file is part of App-nioscli
#
# This software is Copyright (c) 2021 by Christian Segundo.
#
# This is free software, licensed under:
#
#   The Artistic License 2.0 (GPL Compatible)
#

# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.024.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28",
    "perl" => "5.004"
  },
  "dist_abstract" => "CLI for NIOS",
  "dist_author" => [
    "Christian Segundo <ssmn\@cpan.org>"
  ],
  "dist_name" => "App-nioscli",
  "dist_version" => "0.001",
  "license" => "artistic_2",
  "module_name" => "App::nioscli",
  "recursive_test_files" => 1,
  "requires" => {
    "Config::Any" => 0,
    "DNS::NIOS" => "0.004",
    "Devel::OverloadInfo" => 0,
    "IO::Interactive" => 0,
    "MooseX::App" => 0,
    "MooseX::App::Command" => 0,
    "MooseX::App::Role" => 0,
    "YAML" => 0,
    "perl" => "5.006",
    "strictures" => "2.000006"
  },
  "script_files" => [
    "bin/nioscli"
  ],
  "test_requires" => {
    "File::Spec" => 0,
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Test::More" => 0,
    "perl" => "5.006"
  }
);


my %fallback_build_requires = (
  "File::Spec" => 0,
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.28",
  "Test::More" => 0,
  "perl" => "5.006"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
